@@ -32,11 +32,6 @@ class FlaskOIDC(Flask):
         ) or request.endpoint in whitelisted_endpoints.split(","):
             return
 
-        # whitelist all /auth endpoints
-        print(request.endpoint, request.path)
-        if "/auth" in request.path:
-            return
-
         # If accepting token in the request headers
         token = None
         if "Authorization" in request.headers and request.headers[
